"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListTasks = void 0;
const ListTasksCommand_1 = require("../commands/ListTasksCommand");
const ECS_1 = require("../ECS");
const ECSClient_1 = require("../ECSClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListTasksCommand_1.ListTasksCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listTasks(input, ...args);
};
async function* paginateListTasks(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.nextToken = token;
        input["maxResults"] = config.pageSize;
        if (config.client instanceof ECS_1.ECS) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof ECSClient_1.ECSClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected ECS | ECSClient");
        }
        yield page;
        const prevToken = token;
        token = page.nextToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateListTasks = paginateListTasks;
