import { ListClustersCommand, } from "../commands/ListClustersCommand";
import { ECS } from "../ECS";
import { ECSClient } from "../ECSClient";
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListClustersCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listClusters(input, ...args);
};
export async function* paginateListClusters(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.nextToken = token;
        input["maxResults"] = config.pageSize;
        if (config.client instanceof ECS) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof ECSClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected ECS | ECSClient");
        }
        yield page;
        const prevToken = token;
        token = page.nextToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
